summaryrefslogtreecommitdiff
path: root/tikzit/src/gtk/NodeStyleSelector.h
diff options
context:
space:
mode:
Diffstat (limited to 'tikzit/src/gtk/NodeStyleSelector.h')
-rw-r--r--tikzit/src/gtk/NodeStyleSelector.h22
1 files changed, 12 insertions, 10 deletions
diff --git a/tikzit/src/gtk/NodeStyleSelector.h b/tikzit/src/gtk/NodeStyleSelector.h
index 0c83dc0..a699dc8 100644
--- a/tikzit/src/gtk/NodeStyleSelector.h
+++ b/tikzit/src/gtk/NodeStyleSelector.h
@@ -17,12 +17,14 @@
#import "TZFoundation.h"
#import <gtk/gtk.h>
-#import "StyleManager.h"
+
+@class NodeStyle;
+@class NodeStylesModel;
+@class StyleManager;
@interface NodeStyleSelector: NSObject {
- GtkListStore *store;
+ NodeStylesModel *model;
GtkIconView *view;
- StyleManager *styleManager;
}
/*!
@@ -32,10 +34,10 @@
@property (readonly) GtkWidget *widget;
/*!
- @property manager
- @brief The StyleManager to use. Default is [StyleManager manager]
+ @property model
+ @brief The model to use.
*/
-@property (retain) StyleManager *styleManager;
+@property (retain) NodeStylesModel *model;
/*!
@property selectedStyle
@@ -46,13 +48,13 @@
@property (assign) NodeStyle *selectedStyle;
/*!
* Initialise with the default style manager
*/
-- (id) init;
+- (id) initWithStyleManager:(StyleManager*)manager;
/*!
* Initialise with the given style manager
*/
-- (id) initWithStyleManager:(StyleManager*)m;
+- (id) initWithModel:(NodeStylesModel*)model;
@end
@@ -46,13 +48,13 @@
/*!
- * Initialise with the default style manager
+ * Initialise with a new model for the given style manager
*/
@@ -46,13 +48,13 @@
/*!
- * Initialise with the given style manager
+ * Initialise with the given model
*/